@@ -11,7 +11,7 @@ test_that("TestModularity returns correct results",
             mod.test <- TestModularity(cor.matrix, rand.hipots)
             expect_that(dim(mod.test), equals(c(4, 6)))
             expect_that(mod.test[,"hypothesis"], equals(c("1", "2", "3", "Full Integration")))
-            expect_that(colnames(mod.test), equals(c("hypothesis", "Rsquared", "Probability", "AVG+", "AVG-", "AVG Ratio")))
+            expect_that(colnames(mod.test), equals(c("hypothesis", "rho", "Probability", "AVG+", "AVG-", "AVG Ratio")))
             expect_true(all(mod.test[1:4, 2:5] >= -1))
             expect_true(all(mod.test[1:4, 2:5] <= 1))
             expect_that(mod.test[,4]/mod.test[,5], equals(mod.test[,6]))
@@ -28,7 +28,7 @@ test_that("TestModularity returns correct results for Modularity Hypothesis Inde
             mod.test <- TestModularity(cov.matrix, rand.hipots, MHI = TRUE)
             expect_that(dim(mod.test), equals(c(4, 6)))
             expect_that(mod.test[,"hypothesis"], equals(c("1", "2", "3", "Full Integration")))
-            expect_that(colnames(mod.test), equals(c("hypothesis", "Rsquared", 
+            expect_that(colnames(mod.test), equals(c("hypothesis", "rho", 
                                                      "Probability", "AVG+", "AVG-", "MHI")))
             expect_true(all(mod.test[1:4, 2:5] >= -1))
             expect_true(all(mod.test[1:4, 2:5] <= 1))
@@ -43,7 +43,7 @@ test_that("MantelModTest returns correct results for Modularity Hypothesis Index
             cor.hypot = CreateHypotMatrix(hypot)
             
             # First with an unstructured matrix:
-            expect = c(Rsquared = -0.0393920752173473, Probability = 0.556443556443556, 
+            expect = c(rho = -0.0393920752173473, Probability = 0.556443556443556, 
                        `AVG+` = -0.0596580385711816, `AVG-` = -0.0271784073214974, MHI = -0.02718047)
             suppressWarnings(RNGversion("3.5.0"))
             set.seed(42)
@@ -52,7 +52,7 @@ test_that("MantelModTest returns correct results for Modularity Hypothesis Index
             expect_equal(result, expect)
             
             # Now with a modular matrix:
-            expect = c(Rsquared = 1, Probability = 0.001998001998002, `AVG+` = 0.8, 
+            expect = c(rho = 1, Probability = 0.001998001998002, `AVG+` = 0.8, 
                        `AVG-` = 0.3, MHI = 0.325128044)
             suppressWarnings(RNGversion("3.5.0"))
             set.seed(42)
@@ -75,7 +75,7 @@ test_that("MantelModTest returns correct results for non-landmark data",
             cor.hypot = CreateHypotMatrix(hypot)
              
             # First with an unstructured matrix:
-            expect = structure(c(0.0810901974853795, 0.275724275724276, 0.158055575956429, 0.061087664745461, 2.587356655636), .Names = c("Rsquared", "Probability", "AVG+", "AVG-", "AVG Ratio")) 
+            expect = structure(c(0.0810901974853795, 0.275724275724276, 0.158055575956429, 0.061087664745461, 2.587356655636), .Names = c("rho", "Probability", "AVG+", "AVG-", "AVG Ratio")) 
             suppressWarnings(RNGversion("3.5.0"))
             set.seed(42)
             un.cor = RandomMatrix(12, LKJ = FALSE)
@@ -83,7 +83,7 @@ test_that("MantelModTest returns correct results for non-landmark data",
             expect_equal(result, expect)
             
             # Now with a modular matrix:
-            expect = structure(c(0.99102012957595, 0.001998001998002, 0.87040471785857, 0.354135870234584, 2.45782704045767), .Names = c("Rsquared", "Probability", "AVG+", "AVG-", "AVG Ratio"))
+            expect = structure(c(0.99102012957595, 0.001998001998002, 0.87040471785857, 0.354135870234584, 2.45782704045767), .Names = c("rho", "Probability", "AVG+", "AVG-", "AVG Ratio"))
             suppressWarnings(RNGversion("3.5.0"))
             set.seed(42)
             hypot.mask = matrix(as.logical(cor.hypot), 12, 12)
@@ -106,7 +106,7 @@ test_that("MantelModTest returns correct results for landmark data",
             cor.hypot = CreateHypotMatrix(hypot)
             
             # First with an unstructured matrix:
-            expect = structure(c(0.112390456689369, 0.259, 0.209791381269483, 0.0703378394237725, 2.98262475771438, -0.0679013877016532), .Names = c("Rsquared", "Probability", "AVG+", "AVG-", "AVG Ratio", "AVG within landmark"))
+            expect = structure(c(0.112390456689369, 0.259, 0.209791381269483, 0.0703378394237725, 2.98262475771438, -0.0679013877016532), .Names = c("rho", "Probability", "AVG+", "AVG-", "AVG Ratio", "AVG within landmark"))
             suppressWarnings(RNGversion("3.5.0"))
             set.seed(42)
             un.cor = RandomMatrix(12, LKJ = FALSE)
@@ -114,7 +114,7 @@ test_that("MantelModTest returns correct results for landmark data",
             expect_equal(result, expect)
             
             # Now with a modular matrix:
-            expect = structure(c(1, 0, 0.8, 0.3, 2.66666666666667, 0.1), .Names = c("Rsquared","Probability", "AVG+", "AVG-", "AVG Ratio", "AVG within landmark"))
+            expect = structure(c(1, 0, 0.8, 0.3, 2.66666666666667, 0.1), .Names = c("rho","Probability", "AVG+", "AVG-", "AVG Ratio", "AVG within landmark"))
             hypot.mask = matrix(as.logical(cor.hypot), 12, 12)
             mod.cor = matrix(NA, 12, 12)
             mod.cor[ hypot.mask] = 0.8 # within-modules
